/**
 * Class        LcdMenuControlButton.cpp
 * Author       2021-02-02 Charles Geiser
 * 
 * Purpose      Implements a class LcdMenuControlButton  which is derived from the
 *              base class ButtonDebounced. It implements the virtual methods 
 *                onClick()       --> select nextMenuItem
 *                onLongClick()   --> execut action assigned to selected menu item
 *                onDoubleClick   --> select previous menuItem
 *              of the base class.
 *              
 * Board        any
 *  
 * Remarks      The methods of this class handle all the functionality
 *              of the menu system displayed on a LCD with HD44780 controller
 * 
 * References     
 */

#include "LcdMenuControlButton.h"

void LcdMenuControlButton::onClick()
{
  Serial.println("onClick called");
  if (_actionDone)
  {
    _menu.show();           // Shows menu again
    _actionDone = false;
  }
  else
    _menu.nextMenuItem();  
}

void LcdMenuControlButton::onLongClick()
{
  Serial.println("onLongClick called");
  _menu.doAction();         // Do the menu action
  _actionDone = true;
}

void LcdMenuControlButton::onDoubleClick()
{
  Serial.println("onDoubleClick called");
  if (_actionDone)
  {
    _menu.show();           // Shows menu again
    _actionDone = false;
  }
  else
    _menu.prevMenuItem();
}

